complete -c wkd-exporter -l domain -d 'Only export the following domain (may be given multiple times)' -r
complete -c wkd-exporter -l direct -d 'Select direct WKD variant with a filter for this single domain' -r
complete -c wkd-exporter -l append -d 'Append incoming certificates to the ones already existing in `.well-known`'
complete -c wkd-exporter -s h -l help -d 'Print help (see more with \'--help\')'
